/**
 * ### Атрибутная нода
 * Предоставляет интерфейс доступа к содержимому атрибутной ноды
 *
 * Здесь создаются менеджер по работе с атрибутами нодами
 *
 * <br>
 * Связанные объекты:
 *
 * - {@link Trees.GlobalTree.Node} - Здесь можно найти примеры, как работать с вложенными нодами
 * - {@link Trees.GlobalAttributeTree} - Здесь можно найти примеры, как работать с глобальным деревом
 * - {@link Trees.GlobalAttributeTree.Node.Attributes} - Здесь можно найти примеры, как работать с типами ноды
 *
 *
 * @example
 * // Пример: Как получить ноду дерева?
 *
 * // Пример взят для дерева пользовательских данных (т.к. у него есть атрибуты)
 * var tree = null;
 * var node = null;
 *
 * // Осуществляем запрос к менеджеру деревьев, на получение провайдера дерева
 * ps.pl.tm.get(new v2.string("uat")).then(function(ref){
 *     // ref - это ссылка на объект
 *     // метод value возвращает целевой объект. В данном случае дерево Trees.UserAttributeTree
 *     tree = ref.value();
 *
 *     // Доступ к ноде осуществляется похожим образом, но теперь вместо строки нужно указать v2.integer
 *     // Так как возвратится нативный проимс, мы можем вернуть его и обработать в следующем then
 *     return tree.get(v2.integer.from_number(0))
 * }, function(err){
 *     // в случае неудачи придет ошибка.
 *     // обычно в ошибке содержится три переменные err - код ошибки, message - краткое описание, sub - если к этому
 *     // привела другая ошибка внутри системы.
 * }).then(function(ref){
 *     // Вот мы и получили ноду.
 *     node = ref.value();
 * }, function(err){
 *     // Отобразим ошибку
 *     console.warn(err);
 * })
 *
 *
 * @class Node
 * @extends Trees.GlobalTree.Node
 * @memberof Trees.GlobalAttributeTree
 */
function Node() {
    /**
     * Возвращает список всех атрибутов, включая динамические <br>
     * <br> Работает через промис.
     *
     * @public
     * @function attributes
     * @returns {tools.promise}
     * @memberof Trees.GlobalAttributeTree.Node
     */
    this.attributes = function() {

    };

    /**
     * Возвращает список базовых атрибутов ноды (их нельзя удалить) <br>
     * <br> Работает через промис.
     *
     * @public
     * @function base_attributes
     * @returns {tools.promise}
     * @memberof Trees.GlobalAttributeTree.Node
     */
    this.base_attributes = function() {

    };

    /**
     * Возвращает менеджер атрибутов ноды.
     *
     * @public
     * @function am
     * @returns {tools.promise}
     * @memberof Trees.GlobalAttributeTree.Node
     */
    this.am = function() {

    };

    /**
     * Возвращает ссылку на атрибут ноды.
     *  Работает через промис.
     *
     * @public
     * @function get
     * @param {v2.string} attributeName Имя атрибута
     * @returns {tools.promise}
     * @memberof Trees.GlobalAttributeTree.Node
     */
    this.get = function(attributeName) {

    };

}